@@ -246,10 +246,10 @@ impl<O: IsA<FwReq>> FwReqExtManual for O {
         unsafe extern "C" fn responded_trampoline<P, F>(
             this: *mut ffi::HinawaFwReq,
             rcode: ffi::HinawaFwRcode,
-            request_tstamp: libc::c_uint,
-            response_tstamp: libc::c_uint,
+            request_tstamp: std::ffi::c_uint,
+            response_tstamp: std::ffi::c_uint,
             frame: *const u8,
-            length: libc::c_uint,
+            length: std::ffi::c_uint,
             f: glib::ffi::gpointer,
         ) where
             P: IsA<FwReq>,
@@ -268,7 +268,7 @@ impl<O: IsA<FwReq>> FwReqExtManual for O {
             let f: std::boxed::Box<F> = std::boxed::Box::new(f);
             connect_raw(
                 self.as_ptr() as *mut _,
-                b"responded\0".as_ptr() as *const _,
+                c"responded".as_ptr() as *const _,
                 Some(std::mem::transmute::<*const (), unsafe extern "C" fn()>(
                     responded_trampoline::<Self, F> as *const (),
                 )),
