@@ -4,22 +4,27 @@ use super::*;
 
 /// Trait which should be implemented by subclass of [`FwFcp`][crate::FwFcp].
 pub trait FwFcpImpl: ObjectImpl + FwRespImpl {
-    fn responded(&self, fcp: &Self::Type, frame: &[u8]) {
-        self.parent_responded(fcp, frame)
-    }
-    fn responded2(&self, fcp: &Self::Type, tstamp: u32, frame: &[u8]) {
-        self.parent_responded2(fcp, tstamp, frame)
+    /// Class closure for the [`responded`][struct@crate::FwFcp#responded] signal.
+    /// ## `generation`
+    /// The generation of bus topology.
+    /// ## `tstamp`
+    /// The time stamp at which the request subaction arrived for the response of FCP
+    ///     transaction.
+    /// ## `frame`
+    /// The array with elements for byte
+    ///    data in the response of Function Control Protocol.
+    fn responded(&self, fcp: &Self::Type, generation: u32, tstamp: u32, frame: &[u8]) {
+        self.parent_responded(fcp, generation, tstamp, frame)
     }
 }
 
 /// Trait which is automatically implemented to implementator of [`FwFcpImpl`][self::FwFcpImpl].
 pub trait FwFcpImplExt: ObjectSubclass {
-    fn parent_responded(&self, fcp: &Self::Type, frame: &[u8]);
-    fn parent_responded2(&self, fcp: &Self::Type, tstamp: u32, frame: &[u8]);
+    fn parent_responded(&self, fcp: &Self::Type, generation: u32, tstamp: u32, frame: &[u8]);
 }
 
 impl<T: FwFcpImpl> FwFcpImplExt for T {
-    fn parent_responded(&self, fcp: &Self::Type, frame: &[u8]) {
+    fn parent_responded(&self, fcp: &Self::Type, generation: u32, tstamp: u32, frame: &[u8]) {
         unsafe {
             let data = T::type_data();
             let parent_class = data.as_ref().parent_class() as *mut ffi::HinawaFwFcpClass;
@@ -28,20 +33,7 @@ impl<T: FwFcpImpl> FwFcpImplExt for T {
                 .expect("No parent class implementation for \"responded\"");
             f(
                 fcp.unsafe_cast_ref::<FwFcp>().to_glib_none().0,
-                frame.as_ptr(),
-                frame.len() as u32,
-            )
-        }
-    }
-    fn parent_responded2(&self, fcp: &Self::Type, tstamp: u32, frame: &[u8]) {
-        unsafe {
-            let data = T::type_data();
-            let parent_class = data.as_ref().parent_class() as *mut ffi::HinawaFwFcpClass;
-            let f = (*parent_class)
-                .responded2
-                .expect("No parent class implementation for \"responded2\"");
-            f(
-                fcp.unsafe_cast_ref::<FwFcp>().to_glib_none().0,
+                generation,
                 tstamp,
                 frame.as_ptr(),
                 frame.len() as u32,
@@ -56,14 +48,15 @@ unsafe impl<T: FwFcpImpl> IsSubclassable<T> for FwFcp {
 
         let klass = class.as_mut();
         klass.responded = Some(fw_fcp_responded::<T>);
-        klass.responded2 = Some(fw_fcp_responded2::<T>);
     }
 }
 
 unsafe extern "C" fn fw_fcp_responded<T: FwFcpImpl>(
     ptr: *mut ffi::HinawaFwFcp,
+    generation: std::ffi::c_uint,
+    tstamp: std::ffi::c_uint,
     frame: *const u8,
-    length: c_uint,
+    length: std::ffi::c_uint,
 ) {
     let instance = &*(ptr as *mut T::Instance);
     let imp = instance.imp();
@@ -71,22 +64,7 @@ unsafe extern "C" fn fw_fcp_responded<T: FwFcpImpl>(
 
     imp.responded(
         wrap.unsafe_cast_ref(),
-        std::slice::from_raw_parts(frame, length as usize),
-    )
-}
-
-unsafe extern "C" fn fw_fcp_responded2<T: FwFcpImpl>(
-    ptr: *mut ffi::HinawaFwFcp,
-    tstamp: c_uint,
-    frame: *const u8,
-    length: c_uint,
-) {
-    let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.imp();
-    let wrap: Borrowed<FwFcp> = from_glib_borrow(ptr);
-
-    imp.responded2(
-        wrap.unsafe_cast_ref(),
+        generation,
         tstamp,
         std::slice::from_raw_parts(frame, length as usize),
     )
